### Model Settings
```yaml
conf_thresh: 0.5, # Float class confidence threshold
iou_thresh: 0.4, # Float Intersection of Union threshold
device: 'cpu', # Device string used for pytorch (options: 'cpu'| 'gpu')
```

### Model Config
```yaml
input_shape:
filter_class_ids:
classes_len:
model_path:
```